""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.cube.schemas import models

""" Cube API Schema
"""


"""
API: CreateCubePod

创建Pod
"""


class CreateCubePodRequestSchema(schema.RequestSchema):
    """CreateCubePod - 创建Pod"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CpuPlatform": fields.Str(required=False, dump_to="CpuPlatform"),
        "Group": fields.Str(required=False, dump_to="Group"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "Pod": fields.Str(required=True, dump_to="Pod"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateCubePodResponseSchema(schema.ResponseSchema):
    """CreateCubePod - 创建Pod"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "CubeId": fields.Str(required=False, load_from="CubeId"),
        "Pod": fields.Str(required=True, load_from="Pod"),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
    }


"""
API: DeleteCubePod

删除Pod
"""


class DeleteCubePodRequestSchema(schema.RequestSchema):
    """DeleteCubePod - 删除Pod"""

    fields = {
        "CubeId": fields.Str(required=False, dump_to="CubeId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseEIP": fields.Bool(required=False, dump_to="ReleaseEIP"),
        "Uid": fields.Str(required=False, dump_to="Uid"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DeleteCubePodResponseSchema(schema.ResponseSchema):
    """DeleteCubePod - 删除Pod"""

    fields = {}


"""
API: GetCubeExtendInfo

获取Cube的额外信息
"""


class GetCubeExtendInfoRequestSchema(schema.RequestSchema):
    """GetCubeExtendInfo - 获取Cube的额外信息"""

    fields = {
        "CubeIds": fields.Str(required=True, dump_to="CubeIds"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubeExtendInfoResponseSchema(schema.ResponseSchema):
    """GetCubeExtendInfo - 获取Cube的额外信息"""

    fields = {
        "ExtendInfo": fields.List(
            models.CubeExtendInfoSchema(), required=True, load_from="ExtendInfo"
        ),
    }


"""
API: GetCubePod

获取Pod的详细信息
"""


class GetCubePodRequestSchema(schema.RequestSchema):
    """GetCubePod - 获取Pod的详细信息"""

    fields = {
        "CubeId": fields.Str(required=False, dump_to="CubeId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Uid": fields.Str(required=False, dump_to="Uid"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubePodResponseSchema(schema.ResponseSchema):
    """GetCubePod - 获取Pod的详细信息"""

    fields = {
        "Pod": fields.Str(required=True, load_from="Pod"),
    }


"""
API: ListCubePod

获取Pods列表
"""


class ListCubePodRequestSchema(schema.RequestSchema):
    """ListCubePod - 获取Pods列表"""

    fields = {
        "Group": fields.Str(required=False, dump_to="Group"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ListCubePodResponseSchema(schema.ResponseSchema):
    """ListCubePod - 获取Pods列表"""

    fields = {
        "Pods": fields.List(fields.Str(), required=True, load_from="Pods"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: ModifyCubeExtendInfo

修改Cube额外信息
"""


class ModifyCubeExtendInfoRequestSchema(schema.RequestSchema):
    """ModifyCubeExtendInfo - 修改Cube额外信息"""

    fields = {
        "CubeId": fields.Str(required=True, dump_to="CubeId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyCubeExtendInfoResponseSchema(schema.ResponseSchema):
    """ModifyCubeExtendInfo - 修改Cube额外信息"""

    fields = {}


"""
API: RenewCubePod

更新Pod
"""


class RenewCubePodRequestSchema(schema.RequestSchema):
    """RenewCubePod - 更新Pod"""

    fields = {
        "CubeId": fields.Str(required=True, dump_to="CubeId"),
        "Pod": fields.Str(required=True, dump_to="Pod"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class RenewCubePodResponseSchema(schema.ResponseSchema):
    """RenewCubePod - 更新Pod"""

    fields = {
        "Pod": fields.Str(required=True, load_from="Pod"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields
from ucloud.services.unet.schemas import models


""" UNet API Schema
"""


"""
API: AllocateEIP

根据提供信息, 申请弹性IP
"""


class AllocateEIPRequestSchema(schema.RequestSchema):
    """AllocateEIP - 根据提供信息, 申请弹性IP"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "OperatorName": fields.Str(required=True, dump_to="OperatorName"),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "ShareBandwidthId": fields.Str(
            required=False, dump_to="ShareBandwidthId"
        ),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class AllocateEIPResponseSchema(schema.ResponseSchema):
    """AllocateEIP - 根据提供信息, 申请弹性IP"""

    fields = {
        "EIPSet": fields.List(
            models.UnetAllocateEIPSetSchema(),
            required=False,
            load_from="EIPSet",
        )
    }


"""
API: AllocateShareBandwidth

开通共享带宽
"""


class AllocateShareBandwidthRequestSchema(schema.RequestSchema):
    """AllocateShareBandwidth - 开通共享带宽"""

    fields = {
        "BwType": fields.Str(required=False, dump_to="BwType"),
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ShareBandwidth": fields.Int(required=True, dump_to="ShareBandwidth"),
        "ShareBandwidthGuarantee": fields.Int(
            required=False, dump_to="ShareBandwidthGuarantee"
        ),
    }


class AllocateShareBandwidthResponseSchema(schema.ResponseSchema):
    """AllocateShareBandwidth - 开通共享带宽"""

    fields = {
        "ShareBandwidthId": fields.Str(
            required=False, load_from="ShareBandwidthId"
        )
    }


"""
API: AllocateVIP

根据提供信息，申请内网VIP(Virtual IP），多用于高可用程序作为漂移IP。
"""


class AllocateVIPRequestSchema(schema.RequestSchema):
    """AllocateVIP - 根据提供信息，申请内网VIP(Virtual IP），多用于高可用程序作为漂移IP。"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Count": fields.Int(required=False, dump_to="Count"),
        "Ip": fields.Str(required=False, dump_to="Ip"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class AllocateVIPResponseSchema(schema.ResponseSchema):
    """AllocateVIP - 根据提供信息，申请内网VIP(Virtual IP），多用于高可用程序作为漂移IP。"""

    fields = {
        "DataSet": fields.List(
            fields.Str(), required=False, load_from="DataSet"
        ),
        "VIPSet": fields.List(
            models.VIPSetSchema(), required=False, load_from="VIPSet"
        ),
    }


"""
API: AssociateEIPWithShareBandwidth

将EIP加入共享带宽
"""


class AssociateEIPWithShareBandwidthRequestSchema(schema.RequestSchema):
    """AssociateEIPWithShareBandwidth - 将EIP加入共享带宽"""

    fields = {
        "EIPIds": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ShareBandwidthId": fields.Str(
            required=True, dump_to="ShareBandwidthId"
        ),
    }


class AssociateEIPWithShareBandwidthResponseSchema(schema.ResponseSchema):
    """AssociateEIPWithShareBandwidth - 将EIP加入共享带宽"""

    fields = {}


"""
API: BindEIP

将尚未使用的弹性IP绑定到指定的资源
"""


class BindEIPRequestSchema(schema.RequestSchema):
    """BindEIP - 将尚未使用的弹性IP绑定到指定的资源"""

    fields = {
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
        "ResourceType": fields.Str(required=True, dump_to="ResourceType"),
    }


class BindEIPResponseSchema(schema.ResponseSchema):
    """BindEIP - 将尚未使用的弹性IP绑定到指定的资源"""

    fields = {}


"""
API: CreateBandwidthPackage

为非共享带宽模式下, 已绑定资源实例的带宽计费弹性IP附加临时带宽包
"""


class CreateBandwidthPackageRequestSchema(schema.RequestSchema):
    """CreateBandwidthPackage - 为非共享带宽模式下, 已绑定资源实例的带宽计费弹性IP附加临时带宽包"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "EnableTime": fields.Int(required=False, dump_to="EnableTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TimeRange": fields.Int(required=True, dump_to="TimeRange"),
    }


class CreateBandwidthPackageResponseSchema(schema.ResponseSchema):
    """CreateBandwidthPackage - 为非共享带宽模式下, 已绑定资源实例的带宽计费弹性IP附加临时带宽包"""

    fields = {
        "BandwidthPackageId": fields.Str(
            required=False, load_from="BandwidthPackageId"
        )
    }


"""
API: CreateFirewall

创建防火墙
"""


class CreateFirewallRequestSchema(schema.RequestSchema):
    """CreateFirewall - 创建防火墙"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Rule": fields.List(fields.Str()),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class CreateFirewallResponseSchema(schema.ResponseSchema):
    """CreateFirewall - 创建防火墙"""

    fields = {"FWId": fields.Str(required=False, load_from="FWId")}


"""
API: DeleteBandwidthPackage

删除弹性IP上已附加带宽包
"""


class DeleteBandwidthPackageRequestSchema(schema.RequestSchema):
    """DeleteBandwidthPackage - 删除弹性IP上已附加带宽包"""

    fields = {
        "BandwidthPackageId": fields.Str(
            required=True, dump_to="BandwidthPackageId"
        ),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteBandwidthPackageResponseSchema(schema.ResponseSchema):
    """DeleteBandwidthPackage - 删除弹性IP上已附加带宽包"""

    fields = {}


"""
API: DeleteFirewall

删除防火墙
"""


class DeleteFirewallRequestSchema(schema.RequestSchema):
    """DeleteFirewall - 删除防火墙"""

    fields = {
        "FWId": fields.Str(required=True, dump_to="FWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteFirewallResponseSchema(schema.ResponseSchema):
    """DeleteFirewall - 删除防火墙"""

    fields = {}


"""
API: DescribeBandwidthPackage

获取某地域下的带宽包信息
"""


class DescribeBandwidthPackageRequestSchema(schema.RequestSchema):
    """DescribeBandwidthPackage - 获取某地域下的带宽包信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeBandwidthPackageResponseSchema(schema.ResponseSchema):
    """DescribeBandwidthPackage - 获取某地域下的带宽包信息"""

    fields = {
        "DataSets": fields.List(
            models.UnetBandwidthPackageSetSchema(),
            required=False,
            load_from="DataSets",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeBandwidthUsage

获取带宽用量信息
"""


class DescribeBandwidthUsageRequestSchema(schema.RequestSchema):
    """DescribeBandwidthUsage - 获取带宽用量信息"""

    fields = {
        "EIPIds": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "OffSet": fields.Int(required=False, dump_to="OffSet"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeBandwidthUsageResponseSchema(schema.ResponseSchema):
    """DescribeBandwidthUsage - 获取带宽用量信息"""

    fields = {
        "EIPSet": fields.List(
            models.UnetBandwidthUsageEIPSetSchema(),
            required=False,
            load_from="EIPSet",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeEIP

获取弹性IP信息
"""


class DescribeEIPRequestSchema(schema.RequestSchema):
    """DescribeEIP - 获取弹性IP信息"""

    fields = {
        "EIPIds": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeEIPResponseSchema(schema.ResponseSchema):
    """DescribeEIP - 获取弹性IP信息"""

    fields = {
        "EIPSet": fields.List(
            models.UnetEIPSetSchema(), required=False, load_from="EIPSet"
        ),
        "TotalBandwidth": fields.Int(
            required=False, load_from="TotalBandwidth"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeFirewall

获取防火墙组信息
"""


class DescribeFirewallRequestSchema(schema.RequestSchema):
    """DescribeFirewall - 获取防火墙组信息"""

    fields = {
        "FWId": fields.Str(required=False, dump_to="FWId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceId": fields.Str(required=False, dump_to="ResourceId"),
        "ResourceType": fields.Str(required=False, dump_to="ResourceType"),
    }


class DescribeFirewallResponseSchema(schema.ResponseSchema):
    """DescribeFirewall - 获取防火墙组信息"""

    fields = {
        "DataSet": fields.List(
            models.FirewallDataSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeFirewallResource

获取防火墙组所绑定资源的外网IP
"""


class DescribeFirewallResourceRequestSchema(schema.RequestSchema):
    """DescribeFirewallResource - 获取防火墙组所绑定资源的外网IP"""

    fields = {
        "FWId": fields.Str(required=True, dump_to="FWId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeFirewallResourceResponseSchema(schema.ResponseSchema):
    """DescribeFirewallResource - 获取防火墙组所绑定资源的外网IP"""

    fields = {
        "ResourceSet": fields.List(
            models.ResourceSetSchema(), required=False, load_from="ResourceSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeShareBandwidth

获取共享带宽信息
"""


class DescribeShareBandwidthRequestSchema(schema.RequestSchema):
    """DescribeShareBandwidth - 获取共享带宽信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ShareBandwidthIds": fields.List(fields.Str()),
    }


class DescribeShareBandwidthResponseSchema(schema.ResponseSchema):
    """DescribeShareBandwidth - 获取共享带宽信息"""

    fields = {
        "DataSet": fields.List(
            models.UnetShareBandwidthSetSchema(),
            required=False,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeVIP

获取内网VIP详细信息
"""


class DescribeVIPRequestSchema(schema.RequestSchema):
    """DescribeVIP - 获取内网VIP详细信息"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeVIPResponseSchema(schema.ResponseSchema):
    """DescribeVIP - 获取内网VIP详细信息"""

    fields = {
        "DataSet": fields.List(
            fields.Str(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
        "VIPSet": fields.List(
            models.VIPDetailSetSchema(), required=False, load_from="VIPSet"
        ),
    }


"""
API: DisassociateEIPWithShareBandwidth

将EIP移出共享带宽
"""


class DisassociateEIPWithShareBandwidthRequestSchema(schema.RequestSchema):
    """DisassociateEIPWithShareBandwidth - 将EIP移出共享带宽"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "EIPIds": fields.List(fields.Str()),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ShareBandwidthId": fields.Str(
            required=True, dump_to="ShareBandwidthId"
        ),
    }


class DisassociateEIPWithShareBandwidthResponseSchema(schema.ResponseSchema):
    """DisassociateEIPWithShareBandwidth - 将EIP移出共享带宽"""

    fields = {}


"""
API: GetEIPPayMode

获取弹性IP计费模式
"""


class GetEIPPayModeRequestSchema(schema.RequestSchema):
    """GetEIPPayMode - 获取弹性IP计费模式"""

    fields = {
        "EIPId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetEIPPayModeResponseSchema(schema.ResponseSchema):
    """GetEIPPayMode - 获取弹性IP计费模式"""

    fields = {
        "EIPPayMode": fields.List(
            models.EIPPayModeSetSchema(), required=False, load_from="EIPPayMode"
        )
    }


"""
API: GetEIPPrice

获取弹性IP价格
"""


class GetEIPPriceRequestSchema(schema.RequestSchema):
    """GetEIPPrice - 获取弹性IP价格"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "OperatorName": fields.Str(required=True, dump_to="OperatorName"),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetEIPPriceResponseSchema(schema.ResponseSchema):
    """GetEIPPrice - 获取弹性IP价格"""

    fields = {
        "PriceSet": fields.List(
            models.EIPPriceDetailSetSchema(),
            required=False,
            load_from="PriceSet",
        )
    }


"""
API: GetEIPUpgradePrice

获取弹性IP带宽改动价格
"""


class GetEIPUpgradePriceRequestSchema(schema.RequestSchema):
    """GetEIPUpgradePrice - 获取弹性IP带宽改动价格"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetEIPUpgradePriceResponseSchema(schema.ResponseSchema):
    """GetEIPUpgradePrice - 获取弹性IP带宽改动价格"""

    fields = {"Price": fields.Float(required=False, load_from="Price")}


"""
API: GrantFirewall

将防火墙应用到资源上
"""


class GrantFirewallRequestSchema(schema.RequestSchema):
    """GrantFirewall - 将防火墙应用到资源上"""

    fields = {
        "FWId": fields.Str(required=True, dump_to="FWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
        "ResourceType": fields.Str(required=True, dump_to="ResourceType"),
    }


class GrantFirewallResponseSchema(schema.ResponseSchema):
    """GrantFirewall - 将防火墙应用到资源上"""

    fields = {}


"""
API: ModifyEIPBandwidth

调整弹性IP的外网带宽
"""


class ModifyEIPBandwidthRequestSchema(schema.RequestSchema):
    """ModifyEIPBandwidth - 调整弹性IP的外网带宽"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class ModifyEIPBandwidthResponseSchema(schema.ResponseSchema):
    """ModifyEIPBandwidth - 调整弹性IP的外网带宽"""

    fields = {}


"""
API: ModifyEIPWeight

修改弹性IP的外网出口权重
"""


class ModifyEIPWeightRequestSchema(schema.RequestSchema):
    """ModifyEIPWeight - 修改弹性IP的外网出口权重"""

    fields = {
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Weight": fields.Int(required=True, dump_to="Weight"),
    }


class ModifyEIPWeightResponseSchema(schema.ResponseSchema):
    """ModifyEIPWeight - 修改弹性IP的外网出口权重"""

    fields = {}


"""
API: ReleaseEIP

释放弹性IP资源, 所释放弹性IP必须为非绑定状态.
"""


class ReleaseEIPRequestSchema(schema.RequestSchema):
    """ReleaseEIP - 释放弹性IP资源, 所释放弹性IP必须为非绑定状态."""

    fields = {
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class ReleaseEIPResponseSchema(schema.ResponseSchema):
    """ReleaseEIP - 释放弹性IP资源, 所释放弹性IP必须为非绑定状态."""

    fields = {}


"""
API: ReleaseShareBandwidth

关闭共享带宽
"""


class ReleaseShareBandwidthRequestSchema(schema.RequestSchema):
    """ReleaseShareBandwidth - 关闭共享带宽"""

    fields = {
        "EIPBandwidth": fields.Int(required=True, dump_to="EIPBandwidth"),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ShareBandwidthId": fields.Str(
            required=True, dump_to="ShareBandwidthId"
        ),
    }


class ReleaseShareBandwidthResponseSchema(schema.ResponseSchema):
    """ReleaseShareBandwidth - 关闭共享带宽"""

    fields = {}


"""
API: ReleaseVIP

释放VIP资源
"""


class ReleaseVIPRequestSchema(schema.RequestSchema):
    """ReleaseVIP - 释放VIP资源"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VIPId": fields.Str(required=True, dump_to="VIPId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ReleaseVIPResponseSchema(schema.ResponseSchema):
    """ReleaseVIP - 释放VIP资源"""

    fields = {}


"""
API: ResizeShareBandwidth

调整共享带宽的带宽值
"""


class ResizeShareBandwidthRequestSchema(schema.RequestSchema):
    """ResizeShareBandwidth - 调整共享带宽的带宽值"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ShareBandwidth": fields.Int(required=True, dump_to="ShareBandwidth"),
        "ShareBandwidthId": fields.Str(
            required=True, dump_to="ShareBandwidthId"
        ),
    }


class ResizeShareBandwidthResponseSchema(schema.ResponseSchema):
    """ResizeShareBandwidth - 调整共享带宽的带宽值"""

    fields = {}


"""
API: SetEIPPayMode

设置弹性IP计费模式, 切换时会涉及付费/退费.
"""


class SetEIPPayModeRequestSchema(schema.RequestSchema):
    """SetEIPPayMode - 设置弹性IP计费模式, 切换时会涉及付费/退费."""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "PayMode": fields.Str(required=True, dump_to="PayMode"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class SetEIPPayModeResponseSchema(schema.ResponseSchema):
    """SetEIPPayMode - 设置弹性IP计费模式, 切换时会涉及付费/退费."""

    fields = {}


"""
API: UnBindEIP

将弹性IP从资源上解绑
"""


class UnBindEIPRequestSchema(schema.RequestSchema):
    """UnBindEIP - 将弹性IP从资源上解绑"""

    fields = {
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
        "ResourceType": fields.Str(required=True, dump_to="ResourceType"),
    }


class UnBindEIPResponseSchema(schema.ResponseSchema):
    """UnBindEIP - 将弹性IP从资源上解绑"""

    fields = {}


"""
API: UpdateEIPAttribute

更新弹性IP名称，业务组，备注等属性字段
"""


class UpdateEIPAttributeRequestSchema(schema.RequestSchema):
    """UpdateEIPAttribute - 更新弹性IP名称，业务组，备注等属性字段"""

    fields = {
        "EIPId": fields.Str(required=True, dump_to="EIPId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class UpdateEIPAttributeResponseSchema(schema.ResponseSchema):
    """UpdateEIPAttribute - 更新弹性IP名称，业务组，备注等属性字段"""

    fields = {}


"""
API: UpdateFirewall

更新防火墙规则
"""


class UpdateFirewallRequestSchema(schema.RequestSchema):
    """UpdateFirewall - 更新防火墙规则"""

    fields = {
        "FWId": fields.Str(required=True, dump_to="FWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Rule": fields.List(fields.Str()),
    }


class UpdateFirewallResponseSchema(schema.ResponseSchema):
    """UpdateFirewall - 更新防火墙规则"""

    fields = {"FWId": fields.Str(required=False, load_from="FWId")}


"""
API: UpdateFirewallAttribute

更新防火墙规则
"""


class UpdateFirewallAttributeRequestSchema(schema.RequestSchema):
    """UpdateFirewallAttribute - 更新防火墙规则"""

    fields = {
        "FWId": fields.Str(required=True, dump_to="FWId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class UpdateFirewallAttributeResponseSchema(schema.ResponseSchema):
    """UpdateFirewallAttribute - 更新防火墙规则"""

    fields = {}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class PHostIPSetSchema(schema.ResponseSchema):
    """PHostIPSet - DescribePHost"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "IPAddr": fields.Str(required=False, load_from="IPAddr"),
        "IPId": fields.Str(required=False, load_from="IPId"),
        "MACAddr": fields.Str(required=False, load_from="MACAddr"),
        "OperatorName": fields.Str(required=False, load_from="OperatorName"),
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
        "VPCId": fields.Str(required=False, load_from="VPCId"),
    }


class PHostDiskSetSchema(schema.ResponseSchema):
    """PHostDiskSet - GetPHostTypeInfo"""

    fields = {
        "Count": fields.Int(required=False, load_from="Count"),
        "IOCap": fields.Int(required=False, load_from="IOCap"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Space": fields.Int(required=False, load_from="Space"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class PHostCPUSetSchema(schema.ResponseSchema):
    """PHostCPUSet - DescribePHost"""

    fields = {
        "CoreCount": fields.Int(required=False, load_from="CoreCount"),
        "Count": fields.Int(required=False, load_from="Count"),
        "Frequence": fields.Float(required=False, load_from="Frequence"),
        "Model": fields.Str(required=False, load_from="Model"),
    }


class PHostSetSchema(schema.ResponseSchema):
    """PHostSet - DescribePHost"""

    fields = {
        "AutoRenew": fields.Str(required=False, load_from="AutoRenew"),
        "CPUSet": PHostCPUSetSchema(),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "Cluster": fields.Str(required=False, load_from="Cluster"),
        "Components": fields.Str(required=False, load_from="Components"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DiskSet": fields.List(PHostDiskSetSchema()),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "IPSet": fields.List(PHostIPSetSchema()),
        "ImageName": fields.Str(required=False, load_from="ImageName"),
        "IsSupportKVM": fields.Str(required=False, load_from="IsSupportKVM"),
        "Memory": fields.Int(required=False, load_from="Memory"),
        "Name": fields.Str(required=False, load_from="Name"),
        "OSType": fields.Str(required=False, load_from="OSType"),
        "OSname": fields.Str(required=False, load_from="OSname"),
        "PHostId": fields.Str(required=False, load_from="PHostId"),
        "PHostType": fields.Str(required=False, load_from="PHostType"),
        "PMStatus": fields.Str(required=False, load_from="PMStatus"),
        "PowerState": fields.Str(required=False, load_from="PowerState"),
        "RaidSupported": fields.Str(required=False, load_from="RaidSupported"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "SN": fields.Str(required=False, load_from="SN"),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class PHostImageSetSchema(schema.ResponseSchema):
    """PHostImageSet - DescribePHostImage"""

    fields = {
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "ImageName": fields.Str(required=False, load_from="ImageName"),
        "OsName": fields.Str(required=False, load_from="OsName"),
        "OsType": fields.Str(required=False, load_from="OsType"),
    }


class PHostTagSetSchema(schema.ResponseSchema):
    """PHostTagSet - DescribePHostTags"""

    fields = {
        "Tag": fields.Str(required=False, load_from="Tag"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


class PHostPriceSetSchema(schema.ResponseSchema):
    """PHostPriceSet - GetPHostPrice"""

    fields = {
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "Price": fields.Float(required=False, load_from="Price"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class BackendSetSchema(schema.ResponseSchema):
    """BackendSet - ulb添加rs时返回的信息"""

    fields = {
        "BackendId": fields.Str(required=True, load_from="BackendId"),
        "ResourceId": fields.Str(required=True, load_from="ResourceId"),
    }


class ULBSSLSetSchema(schema.ResponseSchema):
    """ULBSSLSet - DescribeULB"""

    fields = {
        "HashValue": fields.Str(required=False, load_from="HashValue"),
        "SSLId": fields.Str(required=False, load_from="SSLId"),
        "SSLName": fields.Str(required=False, load_from="SSLName"),
    }


class PolicyBackendSetSchema(schema.ResponseSchema):
    """PolicyBackendSet - 内容转发下rs详细信息"""

    fields = {
        "BackendId": fields.Str(required=False, load_from="BackendId"),
        "ObjectId": fields.Str(required=False, load_from="ObjectId"),
        "Port": fields.Int(required=False, load_from="Port"),
        "PrivateIP": fields.Str(required=False, load_from="PrivateIP"),
        "ResourceName": fields.Str(required=False, load_from="ResourceName"),
    }


class ULBBackendSetSchema(schema.ResponseSchema):
    """ULBBackendSet - DescribeULB"""

    fields = {
        "BackendId": fields.Str(required=False, load_from="BackendId"),
        "Enabled": fields.Int(required=False, load_from="Enabled"),
        "Port": fields.Int(required=False, load_from="Port"),
        "PrivateIP": fields.Str(required=False, load_from="PrivateIP"),
        "ResourceId": fields.Str(required=False, load_from="ResourceId"),
        "ResourceName": fields.Str(required=False, load_from="ResourceName"),
        "ResourceType": fields.Str(required=False, load_from="ResourceType"),
        "Status": fields.Int(required=False, load_from="Status"),
        "SubResourceId": fields.Str(required=False, load_from="SubResourceId"),
        "SubResourceName": fields.Str(
            required=False, load_from="SubResourceName"
        ),
        "SubResourceType": fields.Str(
            required=False, load_from="SubResourceType"
        ),
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
        "Weight": fields.Int(required=False, load_from="Weight"),
    }


class ULBPolicySetSchema(schema.ResponseSchema):
    """ULBPolicySet - 内容转发详细列表"""

    fields = {
        "BackendSet": fields.List(PolicyBackendSetSchema()),
        "Match": fields.Str(required=False, load_from="Match"),
        "PolicyId": fields.Str(required=False, load_from="PolicyId"),
        "PolicyPriority": fields.Int(
            required=False, load_from="PolicyPriority"
        ),
        "PolicyType": fields.Str(required=False, load_from="PolicyType"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
        "Type": fields.Str(required=False, load_from="Type"),
        "VServerId": fields.Str(required=False, load_from="VServerId"),
    }


class ULBVServerSetSchema(schema.ResponseSchema):
    """ULBVServerSet - DescribeULB"""

    fields = {
        "BackendSet": fields.List(ULBBackendSetSchema()),
        "ClientTimeout": fields.Int(required=False, load_from="ClientTimeout"),
        "Domain": fields.Str(required=True, load_from="Domain"),
        "FrontendPort": fields.Int(required=False, load_from="FrontendPort"),
        "ListenType": fields.Str(required=False, load_from="ListenType"),
        "Method": fields.Str(required=False, load_from="Method"),
        "MonitorType": fields.Str(required=True, load_from="MonitorType"),
        "Path": fields.Str(required=True, load_from="Path"),
        "PersistenceInfo": fields.Str(
            required=False, load_from="PersistenceInfo"
        ),
        "PersistenceType": fields.Str(
            required=False, load_from="PersistenceType"
        ),
        "PolicySet": fields.List(ULBPolicySetSchema()),
        "Protocol": fields.Str(required=False, load_from="Protocol"),
        "SSLSet": fields.List(ULBSSLSetSchema()),
        "Status": fields.Int(required=False, load_from="Status"),
        "VServerId": fields.Str(required=False, load_from="VServerId"),
        "VServerName": fields.Str(required=False, load_from="VServerName"),
    }


class ULBIPSetSchema(schema.ResponseSchema):
    """ULBIPSet - DescribeULB"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "BandwidthType": fields.Int(required=False, load_from="BandwidthType"),
        "EIP": fields.Str(required=False, load_from="EIP"),
        "EIPId": fields.Str(required=False, load_from="EIPId"),
        "OperatorName": fields.Str(required=False, load_from="OperatorName"),
    }


class ULBSetSchema(schema.ResponseSchema):
    """ULBSet - DescribeULB"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "BandwidthType": fields.Int(required=False, load_from="BandwidthType"),
        "BusinessId": fields.Str(required=False, load_from="BusinessId"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "IPSet": fields.List(ULBIPSetSchema()),
        "Name": fields.Str(required=False, load_from="Name"),
        "PrivateIP": fields.Str(required=False, load_from="PrivateIP"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "Resource": fields.List(fields.Str()),
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "ULBId": fields.Str(required=False, load_from="ULBId"),
        "ULBName": fields.Str(required=False, load_from="ULBName"),
        "ULBType": fields.Str(required=False, load_from="ULBType"),
        "VPCId": fields.Str(required=False, load_from="VPCId"),
        "VServerSet": fields.List(ULBVServerSetSchema()),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uk8s.schemas import models

""" UK8S API Schema
"""


"""
API: AddUK8SExistingUHost

将预先创建好的云主机加入到UK8S集群，需要注意的是，该云主机依然会执行重装系统的操作。
"""


class AddUK8SExistingUHostRequestSchema(schema.RequestSchema):
    """AddUK8SExistingUHost - 将预先创建好的云主机加入到UK8S集群，需要注意的是，该云主机依然会执行重装系统的操作。"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "DisableSchedule": fields.Bool(
            required=False, dump_to="DisableSchedule"
        ),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class AddUK8SExistingUHostResponseSchema(schema.ResponseSchema):
    """AddUK8SExistingUHost - 将预先创建好的云主机加入到UK8S集群，需要注意的是，该云主机依然会执行重装系统的操作。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: AddUK8SPHostNode

为UK8S集群添加一台或多台物理云主机类型的节点。
"""


class AddUK8SPHostNodeRequestSchema(schema.RequestSchema):
    """AddUK8SPHostNode - 为UK8S集群添加一台或多台物理云主机类型的节点。"""

    fields = {
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DisableSchedule": fields.Bool(
            required=False, dump_to="DisableSchedule"
        ),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "NIC": fields.Str(required=False, dump_to="NIC"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Raid": fields.Str(required=False, dump_to="Raid"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Type": fields.Str(required=False, dump_to="Type"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class AddUK8SPHostNodeResponseSchema(schema.ResponseSchema):
    """AddUK8SPHostNode - 为UK8S集群添加一台或多台物理云主机类型的节点。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: AddUK8SUHostNode

为UK8S集群添加一台Node节点，机型类型为云主机
"""


class AddUK8SUHostNodeRequestSchema(schema.RequestSchema):
    """AddUK8SUHostNode - 为UK8S集群添加一台Node节点，机型类型为云主机"""

    fields = {
        "BootDiskType": fields.Str(required=False, dump_to="BootDiskType"),
        "CPU": fields.Int(required=True, dump_to="CPU"),
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DataDiskSize": fields.Str(required=False, dump_to="DataDiskSize"),
        "DataDiskType": fields.Str(required=False, dump_to="DataDiskType"),
        "DisableSchedule": fields.Bool(
            required=False, dump_to="DisableSchedule"
        ),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "IsolationGroup": fields.Str(required=False, dump_to="IsolationGroup"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "Mem": fields.Int(required=True, dump_to="Mem"),
        "MinmalCpuPlatform": fields.Str(
            required=False, dump_to="MinmalCpuPlatform"
        ),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class AddUK8SUHostNodeResponseSchema(schema.ResponseSchema):
    """AddUK8SUHostNode - 为UK8S集群添加一台Node节点，机型类型为云主机"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "NodeIds": fields.List(
            fields.Str(), required=False, load_from="NodeIds"
        ),
    }


"""
API: CreateUK8SClusterV2

创建UK8S集群
"""


class CreateUK8SClusterV2ParamMasterSchema(schema.RequestSchema):
    """CreateUK8SClusterV2ParamMaster -"""

    fields = {
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUK8SClusterV2ParamKubeProxySchema(schema.RequestSchema):
    """CreateUK8SClusterV2ParamKubeProxy -"""

    fields = {
        "Mode": fields.Str(required=False, dump_to="Mode"),
    }


class CreateUK8SClusterV2ParamNodesSchema(schema.RequestSchema):
    """CreateUK8SClusterV2ParamNodes -"""

    fields = {
        "BootDiskType": fields.Str(required=False, dump_to="BootDiskType"),
        "CPU": fields.Int(required=True, dump_to="CPU"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DataDiskSize": fields.Int(required=False, dump_to="DataDiskSize"),
        "DataDiskType": fields.Str(required=False, dump_to="DataDiskType"),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "IsolationGroup": fields.Str(required=False, dump_to="IsolationGroup"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MachineType": fields.Str(required=True, dump_to="MachineType"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "Mem": fields.Int(required=True, dump_to="Mem"),
        "MinmalCpuPlatform": fields.Str(
            required=False, dump_to="MinmalCpuPlatform"
        ),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUK8SClusterV2RequestSchema(schema.RequestSchema):
    """CreateUK8SClusterV2 - 创建UK8S集群"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ClusterName": fields.Str(required=True, dump_to="ClusterName"),
        "ExternalApiServer": fields.Str(
            required=False, dump_to="ExternalApiServer"
        ),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "K8sVersion": fields.Str(required=False, dump_to="K8sVersion"),
        "KubeProxy": CreateUK8SClusterV2ParamKubeProxySchema(
            required=False, dump_to="KubeProxy"
        ),
        "Master": fields.List(CreateUK8SClusterV2ParamMasterSchema()),
        "MasterBootDiskType": fields.Str(
            required=False, dump_to="MasterBootDiskType"
        ),
        "MasterCPU": fields.Int(required=True, dump_to="MasterCPU"),
        "MasterDataDiskSize": fields.Int(
            required=False, dump_to="MasterDataDiskSize"
        ),
        "MasterDataDiskType": fields.Str(
            required=False, dump_to="MasterDataDiskType"
        ),
        "MasterIsolationGroup": fields.Str(
            required=False, dump_to="MasterIsolationGroup"
        ),
        "MasterMachineType": fields.Str(
            required=True, dump_to="MasterMachineType"
        ),
        "MasterMem": fields.Int(required=True, dump_to="MasterMem"),
        "MasterMinmalCpuPlatform": fields.Str(
            required=False, dump_to="MasterMinmalCpuPlatform"
        ),
        "Nodes": fields.List(CreateUK8SClusterV2ParamNodesSchema()),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ServiceCIDR": fields.Str(required=True, dump_to="ServiceCIDR"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateUK8SClusterV2ResponseSchema(schema.ResponseSchema):
    """CreateUK8SClusterV2 - 创建UK8S集群"""

    fields = {
        "ClusterId": fields.Str(required=True, load_from="ClusterId"),
    }


"""
API: DelUK8SCluster

删除UK8S集群
"""


class DelUK8SClusterRequestSchema(schema.RequestSchema):
    """DelUK8SCluster - 删除UK8S集群"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseUDisk": fields.Bool(required=False, dump_to="ReleaseUDisk"),
    }


class DelUK8SClusterResponseSchema(schema.ResponseSchema):
    """DelUK8SCluster - 删除UK8S集群"""

    fields = {}


"""
API: DelUK8SClusterNodeV2

删除集群中的Node节点，删除前务必先将其中的Pod驱逐。
"""


class DelUK8SClusterNodeV2RequestSchema(schema.RequestSchema):
    """DelUK8SClusterNodeV2 - 删除集群中的Node节点，删除前务必先将其中的Pod驱逐。"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseDataUDisk": fields.Bool(
            required=False, dump_to="ReleaseDataUDisk"
        ),
    }


class DelUK8SClusterNodeV2ResponseSchema(schema.ResponseSchema):
    """DelUK8SClusterNodeV2 - 删除集群中的Node节点，删除前务必先将其中的Pod驱逐。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: DescribeUK8SImage

获取UK8S支持的Node节点操作系统，可基于该操作系统制定自定义镜像
"""


class DescribeUK8SImageRequestSchema(schema.RequestSchema):
    """DescribeUK8SImage - 获取UK8S支持的Node节点操作系统，可基于该操作系统制定自定义镜像"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUK8SImageResponseSchema(schema.ResponseSchema):
    """DescribeUK8SImage - 获取UK8S支持的Node节点操作系统，可基于该操作系统制定自定义镜像"""

    fields = {
        "ImageSet": fields.List(
            models.ImageInfoSchema(), required=False, load_from="ImageSet"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "PHostImageSet": fields.List(
            models.ImageInfoSchema(), required=False, load_from="PHostImageSet"
        ),
    }


"""
API: ListUK8SClusterNodeV2

获取UK8S集群节点信息
"""


class ListUK8SClusterNodeV2RequestSchema(schema.RequestSchema):
    """ListUK8SClusterNodeV2 - 获取UK8S集群节点信息"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class ListUK8SClusterNodeV2ResponseSchema(schema.ResponseSchema):
    """ListUK8SClusterNodeV2 - 获取UK8S集群节点信息"""

    fields = {
        "NodeSet": fields.List(
            models.NodeInfoV2Schema(), required=True, load_from="NodeSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: ListUK8SClusterV2

获取UK8S集群列表信息
"""


class ListUK8SClusterV2RequestSchema(schema.RequestSchema):
    """ListUK8SClusterV2 - 获取UK8S集群列表信息"""

    fields = {
        "ClusterId": fields.Str(required=False, dump_to="ClusterId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class ListUK8SClusterV2ResponseSchema(schema.ResponseSchema):
    """ListUK8SClusterV2 - 获取UK8S集群列表信息"""

    fields = {
        "ClusterCount": fields.Int(required=True, load_from="ClusterCount"),
        "ClusterSet": fields.List(
            models.ClusterSetSchema(), required=False, load_from="ClusterSet"
        ),
    }



import logging
import time
import typing

from ucloud.client import Client
from ucloud.testing import op
from ucloud.testing.exc import ValueNotFoundError, CompareError, ValidateError

logger = logging.getLogger(__name__)


class Step:
    def __init__(
        self,
        invoker: typing.Callable[[Client, dict], dict],
        max_retries: int = 0,
        retry_interval: int = 0,
        startup_delay: int = 0,
        retry_for: typing.Tuple = (CompareError, ValueNotFoundError),
        fast_fail: bool = False,
        validators: typing.Callable[[dict], typing.List[typing.Tuple]] = None,
        **kwargs
    ):
        """Step is the test step in a test scenario
        :param invoker: invoker is a callable function
        :param max_retries: the maximum retry number by the `retry_for` exception,
                            it will resolve the flaky testing case
        :param retry_interval: the interval between twice retrying
        :param retry_for: the exceptions to retrying
        :param startup_delay: the delay seconds before any action execution
        :param fast_fail: if fast fail is true, the test will fail when got
                          unexpected exception
        :return:
        """
        self.invoker = invoker
        self.max_retries = max_retries
        self.retry_interval = retry_interval
        self.startup_delay = startup_delay
        self.retry_for = retry_for
        self.fast_fail = fast_fail
        self.validators = validators or (lambda _: [])
        self.extras = kwargs

    def run(self, client: Client, variables: dict):
        # wait for delay before startup
        if self.startup_delay:
            time.sleep(self.startup_delay)

        for i in range(self.max_retries + 1):
            # invoke function to load result
            try:
                result = self.invoker(client, variables)
            except self.retry_for as e:
                if i == self.max_retries:
                    raise e

                if self.retry_interval:
                    time.sleep(self.retry_interval)
                continue
            else:
                result = self.set_default_response(result)

            # validate result
            errors = []
            for validator in self.validators(variables):
                try:
                    op.check(
                        validator[0],
                        value_at_path(result, validator[1]),
                        validator[2],
                    )
                except self.retry_for as e:
                    errors.append(e)

            # if got error, retrying or raise it
            if errors:
                if i == self.max_retries:
                    raise ValidateError(errors)

                if self.retry_interval:
                    time.sleep(self.retry_interval)
                continue

            return result

    def set_default_response(self, resp: dict):
        resp = resp.copy()
        resp.setdefault("RetCode", 0)
        if "action" in self.extras:
            resp["Action"] = "{}Response".format(self.extras["action"])
        return resp


class Scenario:
    def __init__(self, id_):
        self.id = id_
        self.variables = {}
        self.errors = []
        self.steps = []

    def summary(self):
        logger.info("=" * 42)
        logger.info("TEST SET {}".format(self.id))
        logger.info("=" * 42)

        if self.errors:
            logger.info("-" * 42)
            logger.info("ERRORS")
            logger.info("-" * 42)
            for err in self.errors:
                logger.error(err)
            logger.info("Errors!")
        else:
            logger.info("Success!")

    def step(
        self,
        max_retries: int = 0,
        retry_interval: int = 0,
        startup_delay: int = 0,
        retry_for: typing.Tuple = (CompareError, ValueNotFoundError),
        fast_fail: bool = False,
        validators: typing.Callable[[dict], typing.List[typing.Tuple]] = None,
        **kwargs
    ):
        def deco(fn: typing.Callable[[Client, dict], dict]):
            step = Step(
                invoker=fn,
                max_retries=max_retries,
                retry_interval=retry_interval,
                startup_delay=startup_delay,
                retry_for=retry_for,
                fast_fail=fast_fail,
                validators=validators,
                **kwargs
            )
            self.steps.append(step)
            return fn

        return deco

    def run(self, client):
        for i, step in enumerate(self.steps):
            try:
                action = step.extras.get("action", "unknown")
                client.logger.info(
                    "running {} step {} {}".format(self.id, i + 1, action)
                )
                step.run(client, self.variables)
            except CompareError as e:
                self.errors.append(e)
                if step.fast_fail:
                    self.summary()
                    raise e
                client.logger.error(e)

        self.summary()

    def initial(self, variables: typing.Optional[dict] = None):
        self.variables = variables


def value_at_path(d: dict, path: str):
    """access value by object path

    :param d: dict or list of dict
    :param path: object path like `Data.1.UHostId`
    :return: any value access by path
    """
    if d is None:
        return

    indices = path.split(".")
    result = d

    for i, key in enumerate(indices):
        if isinstance(result, list):
            if not key.isdigit():
                return

            if len(result) <= int(key):
                msg = "{} not found".format(".".join(indices[: i + 1]))
                raise ValueNotFoundError(msg)

            result = result[int(key)]
            continue

        if isinstance(result, dict):
            result = {k.lower(): v for k, v in result.items()}.get(key.lower())
            if result is None:
                msg = "{} not found".format(".".join(indices[: i + 1]))
                raise ValueNotFoundError(msg)
            continue

    return result



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields
from ucloud.services.uhost.schemas import models


""" UHost API Schema
"""


"""
API: CopyCustomImage

复制自制镜像
"""


class CopyCustomImageRequestSchema(schema.RequestSchema):
    """CopyCustomImage - 复制自制镜像"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SourceImageId": fields.Str(required=True, dump_to="SourceImageId"),
        "TargetImageDescription": fields.Str(
            required=False, dump_to="TargetImageDescription"
        ),
        "TargetImageName": fields.Str(
            required=False, dump_to="TargetImageName"
        ),
        "TargetProjectId": fields.Str(required=True, dump_to="TargetProjectId"),
        "TargetRegion": fields.Str(required=False, dump_to="TargetRegion"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CopyCustomImageResponseSchema(schema.ResponseSchema):
    """CopyCustomImage - 复制自制镜像"""

    fields = {
        "TargetImageId": fields.Str(required=False, load_from="TargetImageId")
    }


"""
API: CreateCustomImage

从指定UHost实例，生成自定义镜像。
"""


class CreateCustomImageRequestSchema(schema.RequestSchema):
    """CreateCustomImage - 从指定UHost实例，生成自定义镜像。"""

    fields = {
        "ImageDescription": fields.Str(
            required=False, dump_to="ImageDescription"
        ),
        "ImageName": fields.Str(required=True, dump_to="ImageName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CreateCustomImageResponseSchema(schema.ResponseSchema):
    """CreateCustomImage - 从指定UHost实例，生成自定义镜像。"""

    fields = {"ImageId": fields.Str(required=False, load_from="ImageId")}


"""
API: CreateUHostInstance

创建UHost实例。
"""


class CreateUHostInstanceParamNetworkInterfaceEIPGlobalSSHSchema(
    schema.RequestSchema
):
    """CreateUHostInstanceParamNetworkInterfaceEIPGlobalSSH -"""

    fields = {
        "Area": fields.Str(required=False, dump_to="Area"),
        "AreaCode": fields.Str(required=False, dump_to="AreaCode"),
        "Port": fields.Int(required=False, dump_to="Port"),
    }


class CreateUHostInstanceParamNetworkInterfaceIPv6Schema(schema.RequestSchema):
    """CreateUHostInstanceParamNetworkInterfaceIPv6 -"""

    fields = {
        "Adress": fields.Str(required=False, dump_to="Adress"),
        "ShareBandwidthId": fields.Str(
            required=False, dump_to="ShareBandwidthId"
        ),
    }


class CreateUHostInstanceParamNetworkInterfaceEIPSchema(schema.RequestSchema):
    """CreateUHostInstanceParamNetworkInterfaceEIP -"""

    fields = {
        "Bandwidth": fields.Int(required=False, dump_to="Bandwidth"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "GlobalSSH": CreateUHostInstanceParamNetworkInterfaceEIPGlobalSSHSchema(
            required=False, dump_to="GlobalSSH"
        ),
        "OperatorName": fields.Str(required=False, dump_to="OperatorName"),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "ShareBandwidthId": fields.Str(
            required=False, dump_to="ShareBandwidthId"
        ),
    }


class CreateUHostInstanceParamNetworkInterfaceSchema(schema.RequestSchema):
    """CreateUHostInstanceParamNetworkInterface -"""

    fields = {
        "EIP": CreateUHostInstanceParamNetworkInterfaceEIPSchema(
            required=False, dump_to="EIP"
        ),
        "IPv6": CreateUHostInstanceParamNetworkInterfaceIPv6Schema(
            required=False, dump_to="IPv6"
        ),
    }


class CreateUHostInstanceParamDisksSchema(schema.RequestSchema):
    """CreateUHostInstanceParamDisks -"""

    fields = {
        "BackupType": fields.Str(required=False, dump_to="BackupType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "Encrypted": fields.Bool(required=False, dump_to="Encrypted"),
        "IsBoot": fields.Str(required=True, dump_to="IsBoot"),
        "KmsKeyId": fields.Str(required=False, dump_to="KmsKeyId"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "Type": fields.Str(required=True, dump_to="Type"),
    }


class CreateUHostInstanceRequestSchema(schema.RequestSchema):
    """CreateUHostInstance - 创建UHost实例。"""

    fields = {
        "AlarmTemplateId": fields.Int(
            required=False, dump_to="AlarmTemplateId"
        ),
        "BootDiskSpace": fields.Int(required=False, dump_to="BootDiskSpace"),
        "CPU": fields.Int(required=False, dump_to="CPU"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DiskPassword": fields.Str(required=False, dump_to="DiskPassword"),
        "DiskSpace": fields.Int(required=False, dump_to="DiskSpace"),
        "Disks": fields.List(CreateUHostInstanceParamDisksSchema()),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "HostIp": fields.Str(required=False, dump_to="HostIp"),
        "HostType": fields.Str(required=False, dump_to="HostType"),
        "HotplugFeature": fields.Bool(required=False, dump_to="HotplugFeature"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "InstallAgent": fields.Str(required=False, dump_to="InstallAgent"),
        "IsolationGroup": fields.Str(required=False, dump_to="IsolationGroup"),
        "KeyPair": fields.Str(required=False, dump_to="KeyPair"),
        "LoginMode": fields.Str(required=True, dump_to="LoginMode"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "MaxCount": fields.Int(required=False, dump_to="MaxCount"),
        "Memory": fields.Int(required=False, dump_to="Memory"),
        "MinimalCpuPlatform": fields.Str(
            required=False, dump_to="MinimalCpuPlatform"
        ),
        "Name": fields.Str(required=False, dump_to="Name"),
        "NetCapability": fields.Str(required=False, dump_to="NetCapability"),
        "NetworkId": fields.Str(required=False, dump_to="NetworkId"),
        "NetworkInterface": fields.List(
            CreateUHostInstanceParamNetworkInterfaceSchema()
        ),
        "Password": fields.Base64(required=True, dump_to="Password"),
        "PrivateIp": fields.List(fields.Str()),
        "PrivateMac": fields.Str(required=False, dump_to="PrivateMac"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceType": fields.Int(required=False, dump_to="ResourceType"),
        "SecurityGroupId": fields.Str(
            required=False, dump_to="SecurityGroupId"
        ),
        "SetId": fields.Int(required=False, dump_to="SetId"),
        "StorageType": fields.Str(required=False, dump_to="StorageType"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "TimemachineFeature": fields.Str(
            required=False, dump_to="TimemachineFeature"
        ),
        "UHostType": fields.Str(required=False, dump_to="UHostType"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "UserDataScript": fields.Str(required=False, dump_to="UserDataScript"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUHostInstanceResponseSchema(schema.ResponseSchema):
    """CreateUHostInstance - 创建UHost实例。"""

    fields = {
        "IPs": fields.List(fields.Str(), required=False, load_from="IPs"),
        "UHostIds": fields.List(
            fields.Str(), required=False, load_from="UHostIds"
        ),
    }


"""
API: DescribeImage

获取指定数据中心镜像列表，用户可通过指定操作系统类型，镜像Id进行过滤。
"""


class DescribeImageRequestSchema(schema.RequestSchema):
    """DescribeImage - 获取指定数据中心镜像列表，用户可通过指定操作系统类型，镜像Id进行过滤。"""

    fields = {
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "ImageType": fields.Str(required=False, dump_to="ImageType"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "OsType": fields.Str(required=False, dump_to="OsType"),
        "PriceSet": fields.Int(required=False, dump_to="PriceSet"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeImageResponseSchema(schema.ResponseSchema):
    """DescribeImage - 获取指定数据中心镜像列表，用户可通过指定操作系统类型，镜像Id进行过滤。"""

    fields = {
        "ImageSet": fields.List(
            models.UHostImageSetSchema(), required=False, load_from="ImageSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeIsolationGroup

查询硬件隔离组列表。
"""


class DescribeIsolationGroupRequestSchema(schema.RequestSchema):
    """DescribeIsolationGroup - 查询硬件隔离组列表。"""

    fields = {
        "GroupId": fields.Str(required=False, dump_to="GroupId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeIsolationGroupResponseSchema(schema.ResponseSchema):
    """DescribeIsolationGroup - 查询硬件隔离组列表。"""

    fields = {
        "IsolationGroupSet": fields.List(
            models.IsolationGroupSchema(),
            required=False,
            load_from="IsolationGroupSet",
        )
    }


"""
API: DescribeUHostInstance

获取主机或主机列表信息，并可根据数据中心，主机ID等参数进行过滤。
"""


class DescribeUHostInstanceRequestSchema(schema.RequestSchema):
    """DescribeUHostInstance - 获取主机或主机列表信息，并可根据数据中心，主机ID等参数进行过滤。"""

    fields = {
        "IsolationGroup": fields.Str(required=False, dump_to="IsolationGroup"),
        "LifeCycle": fields.Int(required=False, dump_to="LifeCycle"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UHostIds": fields.List(fields.Str()),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUHostInstanceResponseSchema(schema.ResponseSchema):
    """DescribeUHostInstance - 获取主机或主机列表信息，并可根据数据中心，主机ID等参数进行过滤。"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
        "UHostSet": fields.List(
            models.UHostInstanceSetSchema(),
            required=False,
            load_from="UHostSet",
        ),
    }


"""
API: DescribeUHostInstanceSnapshot

获取已经存在的UHost实例的存储快照列表。
"""


class DescribeUHostInstanceSnapshotRequestSchema(schema.RequestSchema):
    """DescribeUHostInstanceSnapshot - 获取已经存在的UHost实例的存储快照列表。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUHostInstanceSnapshotResponseSchema(schema.ResponseSchema):
    """DescribeUHostInstanceSnapshot - 获取已经存在的UHost实例的存储快照列表。"""

    fields = {
        "SnapshotSet": fields.List(
            models.UHostSnapshotSetSchema(),
            required=False,
            load_from="SnapshotSet",
        ),
        "UhostId": fields.Str(required=False, load_from="UhostId"),
    }


"""
API: DescribeUHostTags

获取指定数据中心的业务组列表。
"""


class DescribeUHostTagsRequestSchema(schema.RequestSchema):
    """DescribeUHostTags - 获取指定数据中心的业务组列表。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUHostTagsResponseSchema(schema.ResponseSchema):
    """DescribeUHostTags - 获取指定数据中心的业务组列表。"""

    fields = {
        "TagSet": fields.List(
            models.UHostTagSetSchema(), required=False, load_from="TagSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: GetUHostInstancePrice

根据UHost实例配置，获取UHost实例的价格。
"""


class GetUHostInstancePriceParamDisksSchema(schema.RequestSchema):
    """GetUHostInstancePriceParamDisks -"""

    fields = {
        "BackupType": fields.Str(required=False, dump_to="BackupType"),
        "IsBoot": fields.Str(required=True, dump_to="IsBoot"),
        "Size": fields.Int(required=True, dump_to="Size"),
        "Type": fields.Str(required=True, dump_to="Type"),
    }


class GetUHostInstancePriceRequestSchema(schema.RequestSchema):
    """GetUHostInstancePrice - 根据UHost实例配置，获取UHost实例的价格。"""

    fields = {
        "CPU": fields.Int(required=True, dump_to="CPU"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DiskSpace": fields.Int(required=False, dump_to="DiskSpace"),
        "Disks": fields.List(GetUHostInstancePriceParamDisksSchema()),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "LifeCycle": fields.Int(required=False, dump_to="LifeCycle"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "Memory": fields.Int(required=True, dump_to="Memory"),
        "NetCapability": fields.Str(required=False, dump_to="NetCapability"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "StorageType": fields.Str(required=False, dump_to="StorageType"),
        "TimemachineFeature": fields.Str(
            required=False, dump_to="TimemachineFeature"
        ),
        "UHostType": fields.Str(required=False, dump_to="UHostType"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetUHostInstancePriceResponseSchema(schema.ResponseSchema):
    """GetUHostInstancePrice - 根据UHost实例配置，获取UHost实例的价格。"""

    fields = {
        "PriceSet": fields.List(
            models.UHostPriceSetSchema(), required=False, load_from="PriceSet"
        )
    }


"""
API: GetUHostInstanceVncInfo

获取指定UHost实例的管理VNC配置详细信息。
"""


class GetUHostInstanceVncInfoRequestSchema(schema.RequestSchema):
    """GetUHostInstanceVncInfo - 获取指定UHost实例的管理VNC配置详细信息。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetUHostInstanceVncInfoResponseSchema(schema.ResponseSchema):
    """GetUHostInstanceVncInfo - 获取指定UHost实例的管理VNC配置详细信息。"""

    fields = {
        "UhostId": fields.Str(required=False, load_from="UhostId"),
        "VncIP": fields.Str(required=False, load_from="VncIP"),
        "VncPassword": fields.Str(required=False, load_from="VncPassword"),
        "VncPort": fields.Int(required=False, load_from="VncPort"),
    }


"""
API: GetUHostUpgradePrice

获取UHost实例升级配置的价格。可选配置范围请参考[[api:uhost-api:uhost_type|云主机机型说明]]。
"""


class GetUHostUpgradePriceRequestSchema(schema.RequestSchema):
    """GetUHostUpgradePrice - 获取UHost实例升级配置的价格。可选配置范围请参考[[api:uhost-api:uhost_type|云主机机型说明]]。"""

    fields = {
        "BootDiskSpace": fields.Int(required=False, dump_to="BootDiskSpace"),
        "CPU": fields.Int(required=False, dump_to="CPU"),
        "DiskSpace": fields.Int(required=False, dump_to="DiskSpace"),
        "HostType": fields.Str(required=False, dump_to="HostType"),
        "Memory": fields.Int(required=False, dump_to="Memory"),
        "NetCapValue": fields.Int(required=False, dump_to="NetCapValue"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TimemachineFeature": fields.Str(
            required=False, dump_to="TimemachineFeature"
        ),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetUHostUpgradePriceResponseSchema(schema.ResponseSchema):
    """GetUHostUpgradePrice - 获取UHost实例升级配置的价格。可选配置范围请参考[[api:uhost-api:uhost_type|云主机机型说明]]。"""

    fields = {"Price": fields.Float(required=False, load_from="Price")}


"""
API: ImportCustomImage

把UFile的镜像文件导入到UHost，生成自定义镜像
"""


class ImportCustomImageRequestSchema(schema.RequestSchema):
    """ImportCustomImage - 把UFile的镜像文件导入到UHost，生成自定义镜像"""

    fields = {
        "Auth": fields.Bool(required=True, dump_to="Auth"),
        "Format": fields.Str(required=True, dump_to="Format"),
        "ImageDescription": fields.Str(
            required=False, dump_to="ImageDescription"
        ),
        "ImageName": fields.Str(required=True, dump_to="ImageName"),
        "OsName": fields.Str(required=True, dump_to="OsName"),
        "OsType": fields.Str(required=True, dump_to="OsType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UFileUrl": fields.Str(required=True, dump_to="UFileUrl"),
    }


class ImportCustomImageResponseSchema(schema.ResponseSchema):
    """ImportCustomImage - 把UFile的镜像文件导入到UHost，生成自定义镜像"""

    fields = {"ImageId": fields.Str(required=False, load_from="ImageId")}


"""
API: ModifyUHostInstanceName

修改指定UHost实例名称，需要给出数据中心，UHostId，及新的实例名称。
"""


class ModifyUHostInstanceNameRequestSchema(schema.RequestSchema):
    """ModifyUHostInstanceName - 修改指定UHost实例名称，需要给出数据中心，UHostId，及新的实例名称。"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyUHostInstanceNameResponseSchema(schema.ResponseSchema):
    """ModifyUHostInstanceName - 修改指定UHost实例名称，需要给出数据中心，UHostId，及新的实例名称。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: ModifyUHostInstanceRemark

修改指定UHost实例备注信息。
"""


class ModifyUHostInstanceRemarkRequestSchema(schema.RequestSchema):
    """ModifyUHostInstanceRemark - 修改指定UHost实例备注信息。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyUHostInstanceRemarkResponseSchema(schema.ResponseSchema):
    """ModifyUHostInstanceRemark - 修改指定UHost实例备注信息。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: ModifyUHostInstanceTag

修改指定UHost实例业务组标识。
"""


class ModifyUHostInstanceTagRequestSchema(schema.RequestSchema):
    """ModifyUHostInstanceTag - 修改指定UHost实例业务组标识。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyUHostInstanceTagResponseSchema(schema.ResponseSchema):
    """ModifyUHostInstanceTag - 修改指定UHost实例业务组标识。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: PoweroffUHostInstance

直接关闭UHost实例电源，无需等待实例正常关闭。
"""


class PoweroffUHostInstanceRequestSchema(schema.RequestSchema):
    """PoweroffUHostInstance - 直接关闭UHost实例电源，无需等待实例正常关闭。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class PoweroffUHostInstanceResponseSchema(schema.ResponseSchema):
    """PoweroffUHostInstance - 直接关闭UHost实例电源，无需等待实例正常关闭。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: RebootUHostInstance

重新启动UHost实例，需要指定数据中心及UHostID两个参数的值。
"""


class RebootUHostInstanceRequestSchema(schema.RequestSchema):
    """RebootUHostInstance - 重新启动UHost实例，需要指定数据中心及UHostID两个参数的值。"""

    fields = {
        "DiskPassword": fields.Str(required=False, dump_to="DiskPassword"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class RebootUHostInstanceResponseSchema(schema.ResponseSchema):
    """RebootUHostInstance - 重新启动UHost实例，需要指定数据中心及UHostID两个参数的值。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: ReinstallUHostInstance

重新安装指定UHost实例的操作系统
"""


class ReinstallUHostInstanceRequestSchema(schema.RequestSchema):
    """ReinstallUHostInstance - 重新安装指定UHost实例的操作系统"""

    fields = {
        "DNSServers": fields.List(fields.Str()),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "Password": fields.Base64(required=False, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReserveDisk": fields.Str(required=False, dump_to="ReserveDisk"),
        "ResourceType": fields.Int(required=False, dump_to="ResourceType"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ReinstallUHostInstanceResponseSchema(schema.ResponseSchema):
    """ReinstallUHostInstance - 重新安装指定UHost实例的操作系统"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: ResetUHostInstancePassword

重置UHost实例的管理员密码。
"""


class ResetUHostInstancePasswordRequestSchema(schema.RequestSchema):
    """ResetUHostInstancePassword - 重置UHost实例的管理员密码。"""

    fields = {
        "Password": fields.Base64(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ResetUHostInstancePasswordResponseSchema(schema.ResponseSchema):
    """ResetUHostInstancePassword - 重置UHost实例的管理员密码。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: ResizeAttachedDisk

修改挂载的磁盘大小，包含系统盘和数据盘
"""


class ResizeAttachedDiskRequestSchema(schema.RequestSchema):
    """ResizeAttachedDisk - 修改挂载的磁盘大小，包含系统盘和数据盘"""

    fields = {
        "DiskId": fields.Str(required=True, dump_to="DiskId"),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class ResizeAttachedDiskResponseSchema(schema.ResponseSchema):
    """ResizeAttachedDisk - 修改挂载的磁盘大小，包含系统盘和数据盘"""

    fields = {"DiskId": fields.Str(required=False, load_from="DiskId")}


"""
API: ResizeUHostInstance

修改指定UHost实例的资源配置，如CPU核心数，内存容量大小，磁盘空间大小,网络增强等。
"""


class ResizeUHostInstanceRequestSchema(schema.RequestSchema):
    """ResizeUHostInstance - 修改指定UHost实例的资源配置，如CPU核心数，内存容量大小，磁盘空间大小,网络增强等。"""

    fields = {
        "BootDiskSpace": fields.Int(required=False, dump_to="BootDiskSpace"),
        "CPU": fields.Int(required=False, dump_to="CPU"),
        "DiskSpace": fields.Int(required=False, dump_to="DiskSpace"),
        "Memory": fields.Int(required=False, dump_to="Memory"),
        "NetCapValue": fields.Int(required=False, dump_to="NetCapValue"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ResizeUHostInstanceResponseSchema(schema.ResponseSchema):
    """ResizeUHostInstance - 修改指定UHost实例的资源配置，如CPU核心数，内存容量大小，磁盘空间大小,网络增强等。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: StartUHostInstance

启动处于关闭状态的UHost实例，需要指定数据中心及UHostID两个参数的值。
"""


class StartUHostInstanceRequestSchema(schema.RequestSchema):
    """StartUHostInstance - 启动处于关闭状态的UHost实例，需要指定数据中心及UHostID两个参数的值。"""

    fields = {
        "DiskPassword": fields.Str(required=False, dump_to="DiskPassword"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class StartUHostInstanceResponseSchema(schema.ResponseSchema):
    """StartUHostInstance - 启动处于关闭状态的UHost实例，需要指定数据中心及UHostID两个参数的值。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: StopUHostInstance

指停止处于运行状态的UHost实例，需指定数据中心及UhostID。
"""


class StopUHostInstanceRequestSchema(schema.RequestSchema):
    """StopUHostInstance - 指停止处于运行状态的UHost实例，需指定数据中心及UhostID。"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class StopUHostInstanceResponseSchema(schema.ResponseSchema):
    """StopUHostInstance - 指停止处于运行状态的UHost实例，需指定数据中心及UhostID。"""

    fields = {"UhostId": fields.Str(required=False, load_from="UhostId")}


"""
API: TerminateCustomImage

删除用户自定义镜像
"""


class TerminateCustomImageRequestSchema(schema.RequestSchema):
    """TerminateCustomImage - 删除用户自定义镜像"""

    fields = {
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class TerminateCustomImageResponseSchema(schema.ResponseSchema):
    """TerminateCustomImage - 删除用户自定义镜像"""

    fields = {"ImageId": fields.Str(required=False, load_from="ImageId")}


"""
API: TerminateUHostInstance

删除指定数据中心的UHost实例。
"""


class TerminateUHostInstanceRequestSchema(schema.RequestSchema):
    """TerminateUHostInstance - 删除指定数据中心的UHost实例。"""

    fields = {
        "Destroy": fields.Int(required=False, dump_to="Destroy"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseEIP": fields.Bool(required=False, dump_to="ReleaseEIP"),
        "ReleaseUDisk": fields.Bool(required=False, dump_to="ReleaseUDisk"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class TerminateUHostInstanceResponseSchema(schema.ResponseSchema):
    """TerminateUHostInstance - 删除指定数据中心的UHost实例。"""

    fields = {
        "InRecycle": fields.Str(required=True, load_from="InRecycle"),
        "UHostId": fields.Str(required=False, load_from="UHostId"),
    }


"""
API: UpgradeToArkUHostInstance

普通升级为方舟机型
"""


class UpgradeToArkUHostInstanceRequestSchema(schema.RequestSchema):
    """UpgradeToArkUHostInstance - 普通升级为方舟机型"""

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UHostIds": fields.List(fields.Str()),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class UpgradeToArkUHostInstanceResponseSchema(schema.ResponseSchema):
    """UpgradeToArkUHostInstance - 普通升级为方舟机型"""

    fields = {
        "UHostSet": fields.List(
            fields.Str(), required=False, load_from="UHostSet"
        )
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.usms.schemas import apis


class USMSClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(USMSClient, self).__init__(config, transport, middleware, logger)

    def create_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUSMSSignature - 调用接口CreateUSMSSignature申请短信签名

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **CertificateType** (int) - (Required) 签名的资质证明文件类型，需与签名类型保持一致，说明如下：0-三证合一/企业营业执照/组织机构代码证书/社会信用代码证书；1-应用商店后台开发者管理截图；2-备案服务商的备案成功截图(含域名，网站名称，备案号)；3-公众号或小程序的管理界面截图；4-商标注册证书；5-组织机构代码证书、社会信用代码证书；
        - **Description** (str) - (Required) 短信签名申请原因
        - **File** (str) - (Required) 短信签名的资质证明文件，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB
        - **SigContent** (str) - (Required) 短信签名名称；长度为2-12个字符, 可包含中文、数字和符号；无需填写【】或[]，系统会自动添加
        - **SigPurpose** (int) - (Required) 签名用途，0-自用，1-他用；
        - **SigType** (int) - (Required) 签名类型，说明如下：0-公司或企业的全称或简称；1-App应用的全称或简称；2-工信部备案网站的全称或简称；3-公众号或小程序的全称或简称；4-商标名的全称或简称；5-政府/机关事业单位/其他单位的全称或简称；
        - **ProxyFile** (str) - 短信签名授权委托文件，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB；当您是代理并使用第三方的签名时（也即SigPurpose为1-他用），该项为必填项；

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空
        - **SigContent** (str) - 短信签名名称
        - **SigId** (str) - 短信签名ID（短信签名申请时的工单ID）

        """
        # build request
        d = {"ProjectId": self.config.project_id}
        req and d.update(req)
        d = apis.CreateUSMSSignatureRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUSMSSignature", d, **kwargs)
        return apis.CreateUSMSSignatureResponseSchema().loads(resp)

    def create_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUSMSTemplate - 调用接口CreateUSMSTemplate申请短信模板

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **Purpose** (int) - (Required) 短信模板用途类型：1-验证码类短信模板；2-系统通知类短信模板；3-会员推广类短信模板；
        - **Template** (str) - (Required) 短信模板内容，说明如下：字数不超过500，每个中文、符号、英文、数组等都计为一个字；模板中的变量填写格式：{N}，其中N为大于1的整数，有多个参数时，建议N从1开始顺次，例如：{1}、{2}等；短信模板禁止仅包括变量的情况；
        - **TemplateName** (str) - (Required) 短信模板名称，不超过32个字符，每个中文、符号、英文、数字等都计为1个字。
        - **Remark** (str) - 短信模板申请原因说明，字数不超过128，每个中文、符号、英文、数字等都计为1个字。
        - **UnsubscribeInfo** (str) - 当Purpose为3时，也即会员推广类短信模板，该项必填。枚举值：TD退订、回T退订、回N退订、回TD退订、退订回T、退订回D、退订回TD、退订回复T、退订回复D、退订回复N、退订回复TD、拒收回T
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空
        - **TemplateId** (str) - 短信模板ID（短信模板申请时的工单ID）

        """
        # build request
        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
        req and d.update(req)
        d = apis.CreateUSMSTemplateRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUSMSTemplate", d, **kwargs)
        return apis.CreateUSMSTemplateResponseSchema().loads(resp)

    def delete_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUSMSSignature - 调用接口DeleteUSMSSignature删除短信签名

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **SigIds** (list) - (Required) 签名ID（也即短信签名申请时的工单ID），支持以数组的方式，举例，以SigIds.0、SigIds.1...SigIds.N方式传入

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空

        """
        # build request
        d = {"ProjectId": self.config.project_id}
        req and d.update(req)
        d = apis.DeleteUSMSSignatureRequestSchema().dumps(d)

        resp = self.invoke("DeleteUSMSSignature", d, **kwargs)
        return apis.DeleteUSMSSignatureResponseSchema().loads(resp)

    def delete_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUSMSTemplate - 调用接口DeleteUSMSTemplate删除短信模板

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **TemplateIds** (list) - (Required) 模板ID（也即短信模板申请时的工单ID），支持以数组的方式，举例，以TemplateIds.0、TemplateIds.1...TemplateIds.N方式传入
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空

        """
        # build request
        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
        req and d.update(req)
        d = apis.DeleteUSMSTemplateRequestSchema().dumps(d)

        resp = self.invoke("DeleteUSMSTemplate", d, **kwargs)
        return apis.DeleteUSMSTemplateResponseSchema().loads(resp)

    def get_usms_send_receipt(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUSMSSendReceipt - 获取短信发送回执信息。下游服务提供商回执信息返回会有一定延时，建议发送完短信以后，5-10分钟后再调用该接口拉取回执信息。若超过12小时未返回，则请联系技术支持确认原因

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **SessionNoSet** (list) - (Required) 发送短信时返回的SessionNo集合，SessionNoSet.0,SessionNoSet.1....格式
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Data** (list) - 见 **ReceiptPerSession** 模型定义
        - **Message** (str) - 错误描述

        **Response Model**

        **ReceiptPerPhone**

        - **CostCount** (int) - 消耗短信条数
        - **Phone** (str) - 手机号码
        - **ReceiptDesc** (str) - 回执结果描述
        - **ReceiptResult** (str) - 回执结果
        - **ReceiptTime** (int) - 回执返回时间

        **ReceiptPerSession**

        - **ReceiptSet** (list) - 见 **ReceiptPerPhone** 模型定义
        - **SessionNo** (str) - 发送短信时返回的SessionNo

        """
        # build request
        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
        req and d.update(req)
        d = apis.GetUSMSSendReceiptRequestSchema().dumps(d)

        resp = self.invoke("GetUSMSSendReceipt", d, **kwargs)
        return apis.GetUSMSSendReceiptResponseSchema().loads(resp)

    def query_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """QueryUSMSSignature - 调用接口QueryUSMSSignature查询短信签名申请状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **SigContent** (str) - 签名内容；签名ID和签名至少需填写1项；
        - **SigId** (str) - 已申请的短信签名ID（短信签名申请时的工单ID）；签名ID和签名至少需填写1项；

        **Response**

        - **Data** (dict) - 见 **OutSignature** 模型定义
        - **Message** (str) - 发生错误时，表示具体错误描述

        **Response Model**

        **OutSignature**

        - **ErrDesc** (str) - 签名审核失败原因
        - **SigContent** (str) - 签名内容
        - **SigId** (str) - 签名ID
        - **Status** (int) - 签名状态。0-待审核 1-审核中 2-审核通过 3-审核未通过 4-被禁用

        """
        # build request
        d = {"ProjectId": self.config.project_id}
        req and d.update(req)
        d = apis.QueryUSMSSignatureRequestSchema().dumps(d)

        resp = self.invoke("QueryUSMSSignature", d, **kwargs)
        return apis.QueryUSMSSignatureResponseSchema().loads(resp)

    def query_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """QueryUSMSTemplate - 调用接口QueryUSMSTemplate查询短信模板申请状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **TemplateId** (str) - (Required) 模板ID

        **Response**

        - **Data** (dict) - 见 **OutTemplate** 模型定义
        - **Message** (str) - 当RetCode不为0时，Message中显示具体错误描述

        **Response Model**

        **OutTemplate**

        - **CreateTime** (int) - 创建时间
        - **ErrDesc** (str) - 审核失败原因
        - **Purpose** (int) - 模板类型，选项：1-验证码类 2-通知类 3-会员推广类
        - **Remark** (str) - 模板说明
        - **Status** (int) - 短信模板状态；状态说明：0-待审核，1-审核中，2-审核通过，3-审核未通过，4-被禁用
        - **Template** (str) - 短信模板内容
        - **TemplateId** (str) - 短信模板ID
        - **TemplateName** (str) - 短信模板名称
        - **UnsubscribeInfo** (str) - 退订信息；一般填写方式“回T退订”，当purpose为3（也即会员推广类）时，为必填项

        """
        # build request
        d = {"ProjectId": self.config.project_id}
        req and d.update(req)
        d = apis.QueryUSMSTemplateRequestSchema().dumps(d)

        resp = self.invoke("QueryUSMSTemplate", d, **kwargs)
        return apis.QueryUSMSTemplateResponseSchema().loads(resp)

    def send_usms_message(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """SendUSMSMessage - 发送短信息。短信字数超过70个后，按照每66个进行切割(因为要加上1/3), 2/3)等字样，占用4个字长)。短信最大长度不能超过600个字。每个汉字、数字、字母、字符都按一个字计

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PhoneNumbers** (list) - (Required) 电话号码数组，电话号码格式为(60)1xxxxxxxx，()中为国际长途区号(如中国为86或0086，两种格式都支持)，后面为电话号码.若不传入国际区号，如1851623xxxx，则默认为国内手机号
        - **TemplateId** (str) - (Required) 模板ID。若指定的模板ID审核未通过(status不等于2)则不允许发送
        - **TemplateParams** (list) - (Required) 模板参数数组，以TempalteParams.0，TempalteParams.1.。。格式。若模板ID指定的模板无可变参数，则不传入该参数。模板参数个数与模板不匹配，则不允许发送
        - **SigContent** (str) - 使用的签名，如果不输入则使用默认签名，若没有申请默认签名不允许发送；若输入的签名没有申请，则无法发送
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Action** (str) - 操作名称
        - **Message** (str) - 发生错误时表示错误描述
        - **RetCode** (int) - 返回码
        - **SessionNo** (str) - 本次提交发送的短信的唯一ID，可根据该值查询本次发送的短信列表

        """
        # build request
        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
        req and d.update(req)
        d = apis.SendUSMSMessageRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("SendUSMSMessage", d, **kwargs)
        return apis.SendUSMSMessageResponseSchema().loads(resp)

    def update_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUSMSSignature - 调用接口UpdateUSMSSignature修改未通过审核的短信签名，并重新提交审核

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **File** (str) - (Required) 短信签名的资质证明文件，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB
        - **SigContent** (str) - (Required) 新的短信签名名称；长度为2-12个字符, 可包含中文、数字和符号；无需填写【】或[]，系统会自动添加
        - **SigId** (str) - (Required) 签名ID（也即短信签名申请时的工单ID），支持以数组的方式，举例，以SigIds.0、SigIds.1...SigIds.N方式传入
        - **SigPurpose** (int) - (Required) 签名用途，0-自用，1-他用；
        - **SigType** (int) - (Required) 签名类型，说明如下：0-公司或企业的全称或简称；1-App应用的全称或简称；2-工信部备案网站的全称或简称；3-公众号或小程序的全称或简称；4-商标名的全称或简称；5-政府/机关事业单位/其他单位的全称或简称；
        - **CertificateType** (int) - 签名的资质证明文件类型，需与签名类型保持一致，说明如下：0-三证合一/企业营业执照/组织机构代码证书/社会信用代码证书；1-应用商店后台开发者管理截图；2-备案服务商的备案成功截图(含域名，网站名称，备案号)；3-公众号或小程序的管理界面截图；4-商标注册证书；5-组织机构代码证书、社会信用代码证书；
        - **ProxyFile** (str) - 短信签名授权委托文件，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB；当您是代理并使用第三方的签名时（也即SigPurpose为1-他用），该项为必填项；

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空

        """
        # build request
        d = {"ProjectId": self.config.project_id}
        req and d.update(req)
        d = apis.UpdateUSMSSignatureRequestSchema().dumps(d)

        resp = self.invoke("UpdateUSMSSignature", d, **kwargs)
        return apis.UpdateUSMSSignatureResponseSchema().loads(resp)

    def update_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUSMSTemplate - 调用接口UpdateUSMSTemplate修改未通过审核的短信模板，并重新提交审核

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **Template** (str) - (Required) 新的模板内容。模板名称和模板内容必须提供一个，否则会报错。小于等于600个字
        - **TemplateId** (str) - (Required) 短信模板ID
        - **Remark** (str) - 短信模板申请原因说明，字数不超过128，每个中文、符号、英文、数字等都计为1个字。
        - **TemplateName** (str) - 新的模板名称。小于等于32个字，每个中文、英文、数组、符合都计为一个字
        - **UnsubscribeInfo** (str) - 当Purpose为3时，也即会员推广类短信模板，该项必填。枚举值：TD退订、回T退订、回N退订、回TD退订、退订回T、退订回D、退订回TD、退订回复T、退订回复D、退订回复N、退订回复TD、拒收回T
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 发生错误时表示错误描述

        """
        # build request
        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
        req and d.update(req)
        d = apis.UpdateUSMSTemplateRequestSchema().dumps(d)

        resp = self.invoke("UpdateUSMSTemplate", d, **kwargs)
        return apis.UpdateUSMSTemplateResponseSchema().loads(resp)



class Middleware:
    """middleware is the object to store request/response handlers

    >>> middleware = Middleware()

    Add a request handler to prepare the request

    >>> @middleware.request
    ... def prepare(req):
    ...     req['Region'] = 'cn-bj2'
    ...     return req

    Add a response handler to log the response detail

    >>> @middleware.response
    ... def logged(resp):
    ...     print(resp)
    ...     return resp

    >>> len(middleware.request_handlers), len(middleware.response_handlers)
    (1, 1)
    """

    def __init__(self):
        self.request_handlers = []
        self.response_handlers = []
        self.exception_handlers = []

    def request(self, handler, index=-1):
        """request is the request handler register to add request handler.

        :param handler: request handler function, receive request object
                        and return a new request
        :param int index: the position of request in the handler list,
                          default is append it to end
        :return:
        """
        self.request_handlers.insert(index, handler)
        return handler

    def response(self, handler, index=-1):
        """response is the response handler register to add response handler.

        :param handler: response handler function, receive response object
                        and return a new response
        :param int index: the position of response in the handler list,
                          default is append it to end
        :return:
        """
        self.response_handlers.insert(index, handler)
        return handler

    def exception(self, handler, index=-1):
        """exception is the exception handler register to add exception handler.

        :param handler: exception handler function, receive exception object
                        and raise a new exception or ignore it
        :param int index: the position of handler in the handler list,
                          default is append it to end
        :return:
        """
        self.exception_handlers.insert(index, handler)
        return handler



import functools

from ucloud.testing.driver import _step


class Scenario:
    def __init__(self, spec, id_, title=None, owners=None):
        self.id = id_
        self.title = title
        self.store = {}
        self.errors = []
        self.steps = []
        self.spec = spec
        self.owners = owners

    def step(self, invoker, *args, **kwargs):
        step = _step.Step(self, invoker, *args, **kwargs)
        self.steps.append(step)
        return step

    def api(self, **step_kwargs):
        def deco(fn):
            step = self.step(fn, **step_kwargs)

            @functools.wraps(fn)
            def wrapped(*args, **kwargs):
                return step.run_api(*args, **kwargs)

            return wrapped

        return deco

    def func(self, **step_kwargs):
        def deco(fn):
            step = self.step(fn, **step_kwargs)

            @functools.wraps(fn)
            def wrapped(*args, **kwargs):
                return step.run_func(*args, **kwargs)

            return wrapped

        return deco

    @property
    def status(self):
        if all([item.status == "skipped" for item in self.steps]):
            status = "skipped"
        elif any([item.status == "failed" for item in self.steps]):
            status = "failed"
        else:
            status = "passed"
        return status

    @property
    def start_time(self):
        times = [
            item.start_time for item in self.steps if item.status != "skipped"
        ]
        return min(times) if times else 0

    @property
    def end_time(self):
        times = [
            item.end_time for item in self.steps if item.status != "skipped"
        ]
        return max(times) if times else 0

    def json(self):
        return {
            "title": self.title,
            "status": self.status,
            "steps": [item.json() for item in self.steps],
            "owners": self.owners,
            "execution": {
                "duration": self.end_time - self.start_time,
                "start_time": self.start_time,
                "end_time": self.end_time,
            },
            "passed_count": len(
                [1 for item in self.steps if item.status == "passed"]
            ),
            "failed_count": len(
                [1 for item in self.steps if item.status == "failed"]
            ),
            "skipped_count": len(
                [1 for item in self.steps if item.status == "skipped"]
            ),
        }

    def __call__(self, *args, **kwargs):
        for step in self.steps:
            step(step, *args, **kwargs)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields
from ucloud.services.vpc.schemas import models


""" VPC API Schema
"""


"""
API: AddVPCNetwork

添加VPC网段
"""


class AddVPCNetworkRequestSchema(schema.RequestSchema):
    """AddVPCNetwork - 添加VPC网段"""

    fields = {
        "Network": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class AddVPCNetworkResponseSchema(schema.ResponseSchema):
    """AddVPCNetwork - 添加VPC网段"""

    fields = {}


"""
API: AssociateRouteTable

绑定子网的路由表
"""


class AssociateRouteTableRequestSchema(schema.RequestSchema):
    """AssociateRouteTable - 绑定子网的路由表"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class AssociateRouteTableResponseSchema(schema.ResponseSchema):
    """AssociateRouteTable - 绑定子网的路由表"""

    fields = {}


"""
API: CloneRouteTable

根据一张现有路由表复制一张新的路由表
"""


class CloneRouteTableRequestSchema(schema.RequestSchema):
    """CloneRouteTable - 根据一张现有路由表复制一张新的路由表"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
    }


class CloneRouteTableResponseSchema(schema.ResponseSchema):
    """CloneRouteTable - 根据一张现有路由表复制一张新的路由表"""

    fields = {}


"""
API: CreateRouteTable

创建路由表
"""


class CreateRouteTableRequestSchema(schema.RequestSchema):
    """CreateRouteTable - 创建路由表"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateRouteTableResponseSchema(schema.ResponseSchema):
    """CreateRouteTable - 创建路由表"""

    fields = {
        "RouteTableId": fields.Str(required=False, load_from="RouteTableId")
    }


"""
API: CreateSubnet

创建子网
"""


class CreateSubnetRequestSchema(schema.RequestSchema):
    """CreateSubnet - 创建子网"""

    fields = {
        "Netmask": fields.Int(required=False, dump_to="Netmask"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Subnet": fields.Str(required=True, dump_to="Subnet"),
        "SubnetName": fields.Str(required=False, dump_to="SubnetName"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateSubnetResponseSchema(schema.ResponseSchema):
    """CreateSubnet - 创建子网"""

    fields = {"SubnetId": fields.Str(required=False, load_from="SubnetId")}


"""
API: CreateVPC

创建VPC
"""


class CreateVPCRequestSchema(schema.RequestSchema):
    """CreateVPC - 创建VPC"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "Network": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class CreateVPCResponseSchema(schema.ResponseSchema):
    """CreateVPC - 创建VPC"""

    fields = {"VPCId": fields.Str(required=False, load_from="VPCId")}


"""
API: CreateVPCIntercom

新建VPC互通关系
"""


class CreateVPCIntercomRequestSchema(schema.RequestSchema):
    """CreateVPCIntercom - 新建VPC互通关系"""

    fields = {
        "DstProjectId": fields.Str(required=False, dump_to="DstProjectId"),
        "DstRegion": fields.Str(required=False, dump_to="DstRegion"),
        "DstVPCId": fields.Str(required=True, dump_to="DstVPCId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateVPCIntercomResponseSchema(schema.ResponseSchema):
    """CreateVPCIntercom - 新建VPC互通关系"""

    fields = {}


"""
API: DeleteRouteTable

删除自定义路由表
"""


class DeleteRouteTableRequestSchema(schema.RequestSchema):
    """DeleteRouteTable - 删除自定义路由表"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
    }


class DeleteRouteTableResponseSchema(schema.ResponseSchema):
    """DeleteRouteTable - 删除自定义路由表"""

    fields = {}


"""
API: DeleteSubnet

删除子网
"""


class DeleteSubnetRequestSchema(schema.RequestSchema):
    """DeleteSubnet - 删除子网"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class DeleteSubnetResponseSchema(schema.ResponseSchema):
    """DeleteSubnet - 删除子网"""

    fields = {}


"""
API: DeleteVPC

删除VPC
"""


class DeleteVPCRequestSchema(schema.RequestSchema):
    """DeleteVPC - 删除VPC"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class DeleteVPCResponseSchema(schema.ResponseSchema):
    """DeleteVPC - 删除VPC"""

    fields = {}


"""
API: DeleteVPCIntercom

删除VPC互通关系
"""


class DeleteVPCIntercomRequestSchema(schema.RequestSchema):
    """DeleteVPCIntercom - 删除VPC互通关系"""

    fields = {
        "DstProjectId": fields.Str(required=False, dump_to="DstProjectId"),
        "DstRegion": fields.Str(required=False, dump_to="DstRegion"),
        "DstVPCId": fields.Str(required=True, dump_to="DstVPCId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class DeleteVPCIntercomResponseSchema(schema.ResponseSchema):
    """DeleteVPCIntercom - 删除VPC互通关系"""

    fields = {}


"""
API: DescribeRouteTable

获取路由表详细信息(包括路由策略)
"""


class DescribeRouteTableRequestSchema(schema.RequestSchema):
    """DescribeRouteTable - 获取路由表详细信息(包括路由策略)"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "OffSet": fields.Int(required=False, dump_to="OffSet"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=False, dump_to="RouteTableId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeRouteTableResponseSchema(schema.ResponseSchema):
    """DescribeRouteTable - 获取路由表详细信息(包括路由策略)"""

    fields = {
        "RouteTables": fields.List(
            models.RouteTableInfoSchema(),
            required=False,
            load_from="RouteTables",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeSubnet

获取子网信息
"""


class DescribeSubnetRequestSchema(schema.RequestSchema):
    """DescribeSubnet - 获取子网信息"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=False, dump_to="RouteTableId"),
        "ShowAvailableIPs": fields.Bool(
            required=False, dump_to="ShowAvailableIPs"
        ),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "SubnetIds": fields.List(fields.Str()),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeSubnetResponseSchema(schema.ResponseSchema):
    """DescribeSubnet - 获取子网信息"""

    fields = {
        "DataSet": fields.List(
            models.SubnetInfoSchema(), required=True, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeSubnetResource

展示子网资源
"""


class DescribeSubnetResourceRequestSchema(schema.RequestSchema):
    """DescribeSubnetResource - 展示子网资源"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceType": fields.Str(required=False, dump_to="ResourceType"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class DescribeSubnetResourceResponseSchema(schema.ResponseSchema):
    """DescribeSubnetResource - 展示子网资源"""

    fields = {
        "DataSet": fields.List(
            models.SubnetResourceSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeVPC

获取VPC信息
"""


class DescribeVPCRequestSchema(schema.RequestSchema):
    """DescribeVPC - 获取VPC信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCIds": fields.List(fields.Str()),
    }


class DescribeVPCResponseSchema(schema.ResponseSchema):
    """DescribeVPC - 获取VPC信息"""

    fields = {
        "DataSet": fields.List(
            models.VPCInfoSchema(), required=False, load_from="DataSet"
        )
    }


"""
API: DescribeVPCIntercom

获取VPC互通信息
"""


class DescribeVPCIntercomRequestSchema(schema.RequestSchema):
    """DescribeVPCIntercom - 获取VPC互通信息"""

    fields = {
        "DstProjectId": fields.Str(required=False, dump_to="DstProjectId"),
        "DstRegion": fields.Str(required=False, dump_to="DstRegion"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class DescribeVPCIntercomResponseSchema(schema.ResponseSchema):
    """DescribeVPCIntercom - 获取VPC互通信息"""

    fields = {
        "DataSet": fields.List(
            models.VPCIntercomInfoSchema(), required=False, load_from="DataSet"
        )
    }


"""
API: ModifyRouteRule

路由策略增、删、改
"""


class ModifyRouteRuleRequestSchema(schema.RequestSchema):
    """ModifyRouteRule - 路由策略增、删、改"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteRule": fields.List(fields.Str()),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
    }


class ModifyRouteRuleResponseSchema(schema.ResponseSchema):
    """ModifyRouteRule - 路由策略增、删、改"""

    fields = {}


"""
API: UpdateRouteTableAttribute

更新路由表基本信息
"""


class UpdateRouteTableAttributeRequestSchema(schema.RequestSchema):
    """UpdateRouteTableAttribute - 更新路由表基本信息"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class UpdateRouteTableAttributeResponseSchema(schema.ResponseSchema):
    """UpdateRouteTableAttribute - 更新路由表基本信息"""

    fields = {}


"""
API: UpdateSubnetAttribute

更新子网信息
"""


class UpdateSubnetAttributeRequestSchema(schema.RequestSchema):
    """UpdateSubnetAttribute - 更新子网信息"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class UpdateSubnetAttributeResponseSchema(schema.ResponseSchema):
    """UpdateSubnetAttribute - 更新子网信息"""

    fields = {}


"""
API: UpdateVPCNetwork

更新VPC网段
"""


class UpdateVPCNetworkRequestSchema(schema.RequestSchema):
    """UpdateVPCNetwork - 更新VPC网段"""

    fields = {
        "Network": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class UpdateVPCNetworkResponseSchema(schema.ResponseSchema):
    """UpdateVPCNetwork - 更新VPC网段"""

    fields = {"Message": fields.Str(required=True, load_from="Message")}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uhub.schemas import models

""" UHub API Schema
"""


"""
API: CreateRepo

创建镜像仓库
"""


class CreateRepoRequestSchema(schema.RequestSchema):
    """CreateRepo - 创建镜像仓库"""

    fields = {
        "Description": fields.Str(required=False, dump_to="Description"),
        "IsShared": fields.Bool(required=False, dump_to="IsShared"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RepoName": fields.Str(required=True, dump_to="RepoName"),
    }


class CreateRepoResponseSchema(schema.ResponseSchema):
    """CreateRepo - 创建镜像仓库"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: DeleteRepo

删除镜像仓库
"""


class DeleteRepoRequestSchema(schema.RequestSchema):
    """DeleteRepo - 删除镜像仓库"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RepoName": fields.Str(required=True, dump_to="RepoName"),
    }


class DeleteRepoResponseSchema(schema.ResponseSchema):
    """DeleteRepo - 删除镜像仓库"""

    fields = {}


"""
API: DeleteRepoImage

删除镜像
"""


class DeleteRepoImageRequestSchema(schema.RequestSchema):
    """DeleteRepoImage - 删除镜像"""

    fields = {
        "ImageName": fields.Str(required=True, dump_to="ImageName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RepoName": fields.Str(required=True, dump_to="RepoName"),
        "TagName": fields.Str(required=False, dump_to="TagName"),
    }


class DeleteRepoImageResponseSchema(schema.ResponseSchema):
    """DeleteRepoImage - 删除镜像"""

    fields = {}


"""
API: GetImageTag

获取镜像tag
"""


class GetImageTagRequestSchema(schema.RequestSchema):
    """GetImageTag - 获取镜像tag"""

    fields = {
        "ImageName": fields.Str(required=True, dump_to="ImageName"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RepoName": fields.Str(required=True, dump_to="RepoName"),
        "TagName": fields.Str(required=False, dump_to="TagName"),
    }


class GetImageTagResponseSchema(schema.ResponseSchema):
    """GetImageTag - 获取镜像tag"""

    fields = {
        "TagSet": fields.List(
            models.TagSetSchema(), required=True, load_from="TagSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetRepo

获取镜像仓库
"""


class GetRepoRequestSchema(schema.RequestSchema):
    """GetRepo - 获取镜像仓库"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Str(required=False, dump_to="Type"),
    }


class GetRepoResponseSchema(schema.ResponseSchema):
    """GetRepo - 获取镜像仓库"""

    fields = {
        "RepoSet": fields.List(
            models.RepoSetSchema(), required=True, load_from="RepoSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetRepoImage

获取镜像仓库下的镜像
"""


class GetRepoImageRequestSchema(schema.RequestSchema):
    """GetRepoImage - 获取镜像仓库下的镜像"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RepoName": fields.Str(required=True, dump_to="RepoName"),
    }


class GetRepoImageResponseSchema(schema.ResponseSchema):
    """GetRepoImage - 获取镜像仓库下的镜像"""

    fields = {
        "ImageSet": fields.List(
            models.ImageSetSchema(), required=True, load_from="ImageSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: UpdateRepo

更新镜像仓库
"""


class UpdateRepoRequestSchema(schema.RequestSchema):
    """UpdateRepo - 更新镜像仓库"""

    fields = {
        "Description": fields.Str(required=False, dump_to="Description"),
        "IsShared": fields.Str(required=False, dump_to="IsShared"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RepoName": fields.Str(required=True, dump_to="RepoName"),
    }


class UpdateRepoResponseSchema(schema.ResponseSchema):
    """UpdateRepo - 更新镜像仓库"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.ipsecvpn.schemas import models

""" IPSecVPN API Schema
"""


"""
API: DescribeRemoteVPNGateway

获取客户VPN网关信息
"""


class DescribeRemoteVPNGatewayRequestSchema(schema.RequestSchema):
    """DescribeRemoteVPNGateway - 获取客户VPN网关信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RemoteVPNGatewayIds": fields.List(fields.Str()),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class DescribeRemoteVPNGatewayResponseSchema(schema.ResponseSchema):
    """DescribeRemoteVPNGateway - 获取客户VPN网关信息"""

    fields = {
        "DataSet": fields.List(
            models.RemoteVPNGatewayDataSetSchema(),
            required=False,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeVPNTunnel

获取VPN隧道信息
"""


class DescribeVPNTunnelRequestSchema(schema.RequestSchema):
    """DescribeVPNTunnel - 获取VPN隧道信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPNTunnelIds": fields.List(fields.Str()),
    }


class DescribeVPNTunnelResponseSchema(schema.ResponseSchema):
    """DescribeVPNTunnel - 获取VPN隧道信息"""

    fields = {
        "DataSet": fields.List(
            models.VPNTunnelDataSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }
